==> koffice-1.2.1.tar.bz2: koffice-1.2.1/kivio/plugins/kivioselecttool/plugin.cpp <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#include "plugin.h"
#include "tool_select.h"

#include "kivio_view.h"

#include <kinstance.h>
#include <kiconloader.h>

/***************************************************
 * Factory
 ***************************************************/
extern "C"
{
  void* init_libkivioselecttool()
  {
    return new SelectToolFactory;
  }
};

KInstance* SelectToolFactory::s_global = 0;

SelectToolFactory::SelectToolFactory( QObject* parent, const char* name )
: KLibFactory( parent, name )
{
  s_global = new KInstance("kivio");
}

SelectToolFactory::~SelectToolFactory()
{
  delete s_global;
}

QObject* SelectToolFactory::createObject( QObject* parent, const char* name, const char*, const QStringList& )
{
  if ( !parent->inherits("KivioView") )
    return 0;

  QObject *obj = new SelectTool( (KivioView*)parent );
  return obj;
}

KInstance* SelectToolFactory::global()
{
  return s_global;
}
#include "plugin.moc"

==> koffice-1.3.1.tar.bz2: koffice-1.3.1/kivio/plugins/kivioselecttool/plugin.cpp <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#include "plugin.h"
#include "tool_select.h"

#include "kivio_view.h"

#include <kinstance.h>
#include <kiconloader.h>

/***************************************************
 * Factory
 ***************************************************/
extern "C"
{
  void* init_libkivioselecttool()
  {
    return new SelectToolFactory;
  }
}

KInstance* SelectToolFactory::s_global = 0;

SelectToolFactory::SelectToolFactory( QObject* parent, const char* name )
: KLibFactory( parent, name )
{
  s_global = new KInstance("kivio");
}

SelectToolFactory::~SelectToolFactory()
{
  delete s_global;
}

QObject* SelectToolFactory::createObject( QObject* parent, const char*, const char*, const QStringList& )
{
  if ( !parent->inherits("KivioView") )
    return 0;

  QObject *obj = new SelectTool( (KivioView*)parent );
  return obj;
}

KInstance* SelectToolFactory::global()
{
  return s_global;
}
#include "plugin.moc"
